@@ -1,3 +1,4 @@
+import nwborglab
 import os
 from datetime import datetime as dt
 from SAPOFTO import SAPOFTO
@@ -47,7 +48,14 @@ def init(args):
     tab = '    '
     half_tab = '  '
 
-    print('args')
+
+    if not os.path.isfile('~/.nwborglabsrc.org'):
+        print('First nwborglab initialization! Setting up... ')
+        with open('/'.join(nwborglab.__file__.split('/')[:-1]) + '/' + '.nwborglabsrc.org', 'r') as f: # TODO replace this with where the package will be
+            content = f.read()
+        with open('~/.nwborglabsrc.org', 'w') as f: # TODO replace this with where the package will be
+            f.write(content)
+
     if os.path.isfile('.nwborglab.org'):
         print('ERROR: This directory is already the root of an nwborg project.')
         return
@@ -55,7 +63,7 @@ def init(args):
     # TODO fill out the .nwborg
     init_org = SAPOFTO.SAPOFTO('.nwborglab')
     content = ''
-    with open('.nwborglabsrc.org', 'r') as f: # TODO replace this with where the package will be
+    with open('~/.nwborglabsrc.org', 'r') as f: # TODO replace this with where the package will be
         content = f.read()
     with open('.nwborglab.org', 'w') as f:
         f.write(content)
